@@ -316,32 +316,42 @@ class TestCase(unittest.TestCase):
             mock.call(
                 mock.ANY,
                 [
-                    utils.get_data_files_path("ansible", "ssh-known-host.yml"),
                     utils.get_data_files_path(
-                        "ansible", "kayobe-ansible-user.yml"),
-                    utils.get_data_files_path("ansible", "apt.yml"),
-                    utils.get_data_files_path("ansible", "dnf.yml"),
-                    utils.get_data_files_path("ansible", "pip.yml"),
-                    utils.get_data_files_path(
-                        "ansible", "kayobe-target-venv.yml"),
-                    utils.get_data_files_path("ansible", "users.yml"),
-                    utils.get_data_files_path("ansible", "dev-tools.yml"),
-                    utils.get_data_files_path("ansible", "network.yml"),
-                    utils.get_data_files_path("ansible", "firewall.yml"),
-                    utils.get_data_files_path("ansible", "tuned.yml"),
-                    utils.get_data_files_path("ansible", "sysctl.yml"),
-                    utils.get_data_files_path("ansible", "time.yml"),
-                    utils.get_data_files_path("ansible", "mdadm.yml"),
-                    utils.get_data_files_path("ansible", "luks.yml"),
-                    utils.get_data_files_path("ansible", "lvm.yml"),
-                    utils.get_data_files_path(
-                        "ansible", "seed-hypervisor-libvirt-host.yml"),
+                        "ansible", "seed-hypervisor-host-configure.yml"),
                 ],
                 limit="seed-hypervisor",
             ),
         ]
         self.assertEqual(expected_calls, mock_run.call_args_list)
 
+    @mock.patch.object(commands.KayobeAnsibleMixin,
+                       "run_kayobe_playbooks")
+    def test_seed_hypervisor_host_configure_wipe_disks(self, mock_run):
+        command = commands.SeedHypervisorHostConfigure(TestApp(), [])
+        parser = command.get_parser("test")
+        parsed_args = parser.parse_args(["--wipe-disks"])
+
+        result = command.run(parsed_args)
+        self.assertEqual(0, result)
+
+        expected_calls = [
+            mock.call(
+                mock.ANY,
+                [utils.get_data_files_path("ansible", "ip-allocation.yml")],
+                limit="seed-hypervisor",
+            ),
+            mock.call(
+                mock.ANY,
+                [
+                    utils.get_data_files_path(
+                        "ansible", "seed-hypervisor-host-configure.yml"),
+                ],
+                limit="seed-hypervisor",
+                extra_vars={"wipe_disks": True},
+            ),
+        ]
+        self.assertEqual(expected_calls, mock_run.call_args_list)
+
     @mock.patch.object(commands.KayobeAnsibleMixin,
                        "run_kayobe_playbooks")
     def test_seed_hypervisor_host_command_run(self, mock_run):
@@ -489,36 +499,8 @@ class TestCase(unittest.TestCase):
             mock.call(
                 mock.ANY,
                 [
-                    utils.get_data_files_path("ansible", "ssh-known-host.yml"),
                     utils.get_data_files_path(
-                        "ansible", "kayobe-ansible-user.yml"),
-                    utils.get_data_files_path("ansible", "apt.yml"),
-                    utils.get_data_files_path("ansible", "dnf.yml"),
-                    utils.get_data_files_path("ansible", "pip.yml"),
-                    utils.get_data_files_path(
-                        "ansible", "kayobe-target-venv.yml"),
-                    utils.get_data_files_path("ansible", "users.yml"),
-                    utils.get_data_files_path("ansible", "dev-tools.yml"),
-                    utils.get_data_files_path(
-                        "ansible", "disable-selinux.yml"),
-                    utils.get_data_files_path("ansible", "network.yml"),
-                    utils.get_data_files_path("ansible", "firewall.yml"),
-                    utils.get_data_files_path("ansible", "tuned.yml"),
-                    utils.get_data_files_path("ansible", "sysctl.yml"),
-                    utils.get_data_files_path("ansible", "ip-routing.yml"),
-                    utils.get_data_files_path("ansible", "snat.yml"),
-                    utils.get_data_files_path("ansible", "disable-glean.yml"),
-                    utils.get_data_files_path("ansible", "time.yml"),
-                    utils.get_data_files_path("ansible", "mdadm.yml"),
-                    utils.get_data_files_path("ansible", "luks.yml"),
-                    utils.get_data_files_path("ansible", "lvm.yml"),
-                    utils.get_data_files_path("ansible",
-                                              "docker-devicemapper.yml"),
-                    utils.get_data_files_path(
-                        "ansible", "kolla-ansible-user.yml"),
-                    utils.get_data_files_path("ansible", "kolla-pip.yml"),
-                    utils.get_data_files_path(
-                        "ansible", "kolla-target-venv.yml"),
+                        "ansible", "seed-host-configure.yml"),
                 ],
                 limit="seed",
             ),
@@ -531,7 +513,6 @@ class TestCase(unittest.TestCase):
             mock.call(
                 mock.ANY,
                 [
-                    utils.get_data_files_path("ansible", "kolla-host.yml"),
                     utils.get_data_files_path("ansible", "docker.yml"),
                 ],
                 limit="seed",
@@ -556,6 +537,68 @@ class TestCase(unittest.TestCase):
         ]
         self.assertEqual(expected_calls, mock_kolla_run.call_args_list)
 
+    @mock.patch.object(commands.KayobeAnsibleMixin,
+                       "run_kayobe_playbooks")
+    @mock.patch.object(commands.KollaAnsibleMixin,
+                       "run_kolla_ansible_seed")
+    def test_seed_host_configure_wipe_disks(self, mock_kolla_run, mock_run):
+        command = commands.SeedHostConfigure(TestApp(), [])
+        parser = command.get_parser("test")
+        parsed_args = parser.parse_args(["--wipe-disks"])
+
+        result = command.run(parsed_args)
+        self.assertEqual(0, result)
+
+        expected_calls = [
+            mock.call(
+                mock.ANY,
+                [utils.get_data_files_path("ansible", "ip-allocation.yml")],
+                limit="seed",
+            ),
+            mock.call(
+                mock.ANY,
+                [
+                    utils.get_data_files_path(
+                        "ansible", "seed-host-configure.yml"),
+                ],
+                limit="seed",
+                extra_vars={"wipe_disks": True},
+            ),
+            mock.call(
+                mock.ANY,
+                [utils.get_data_files_path("ansible", "kolla-ansible.yml")],
+                tags="config",
+                ignore_limit=True,
+            ),
+            mock.call(
+                mock.ANY,
+                [
+                    utils.get_data_files_path("ansible", "docker.yml"),
+                ],
+                limit="seed",
+            ),
+            mock.call(
+                mock.ANY,
+                [
+                    utils.get_data_files_path("ansible",
+                                              "docker-registry.yml"),
+                ],
+                limit="seed",
+                extra_vars={'kayobe_action': 'deploy'},
+            ),
+        ]
+        print(expected_calls)
+        print(mock_run.call_args_list)
+        self.assertEqual(expected_calls, mock_run.call_args_list)
+
+        expected_calls = [
+            mock.call(
+                mock.ANY,
+                "bootstrap-servers",
+            ),
+        ]
+        self.assertEqual(expected_calls, mock_kolla_run.call_args_list)
+
     @mock.patch.object(commands.KayobeAnsibleMixin,
                        "run_kayobe_playbooks")
     def test_seed_host_command_run(self, mock_run):
@@ -675,9 +718,7 @@ class TestCase(unittest.TestCase):
                 mock.ANY,
                 [
                     utils.get_data_files_path(
-                        "ansible", "kayobe-target-venv.yml"),
-                    utils.get_data_files_path(
-                        "ansible", "kolla-target-venv.yml"),
+                        "ansible", "seed-host-upgrade.yml"),
                 ],
                 limit="seed",
             ),
@@ -981,38 +1022,42 @@ class TestCase(unittest.TestCase):
             mock.call(
                 mock.ANY,
                 [
-                    utils.get_data_files_path("ansible", "ssh-known-host.yml"),
                     utils.get_data_files_path(
-                        "ansible", "kayobe-ansible-user.yml"),
-                    utils.get_data_files_path("ansible", "apt.yml"),
-                    utils.get_data_files_path("ansible", "dnf.yml"),
-                    utils.get_data_files_path("ansible", "pip.yml"),
-                    utils.get_data_files_path(
-                        "ansible", "kayobe-target-venv.yml"),
-                    utils.get_data_files_path("ansible", "users.yml"),
-                    utils.get_data_files_path("ansible", "dev-tools.yml"),
-                    utils.get_data_files_path(
-                        "ansible", "disable-selinux.yml"),
-                    utils.get_data_files_path("ansible", "network.yml"),
-                    utils.get_data_files_path("ansible", "firewall.yml"),
-                    utils.get_data_files_path("ansible", "tuned.yml"),
-                    utils.get_data_files_path("ansible", "sysctl.yml"),
-                    utils.get_data_files_path("ansible", "disable-glean.yml"),
-                    utils.get_data_files_path(
-                        "ansible", "disable-cloud-init.yml"),
-                    utils.get_data_files_path("ansible", "time.yml"),
-                    utils.get_data_files_path("ansible", "mdadm.yml"),
-                    utils.get_data_files_path("ansible", "luks.yml"),
-                    utils.get_data_files_path("ansible", "lvm.yml"),
-                    utils.get_data_files_path("ansible",
-                                              "docker-devicemapper.yml"),
-                    utils.get_data_files_path("ansible", "docker.yml"),
+                        "ansible", "infra-vm-host-configure.yml"),
                 ],
                 limit="infra-vms",
             ),
         ]
         self.assertEqual(expected_calls, mock_run.call_args_list)
 
+    @mock.patch.object(commands.KayobeAnsibleMixin,
+                       "run_kayobe_playbooks")
+    def test_infra_vm_host_configure_wipe_disks(self, mock_run):
+        command = commands.InfraVMHostConfigure(TestApp(), [])
+        parser = command.get_parser("test")
+        parsed_args = parser.parse_args(["--wipe-disks"])
+
+        result = command.run(parsed_args)
+        self.assertEqual(0, result)
+
+        expected_calls = [
+            mock.call(
+                mock.ANY,
+                [utils.get_data_files_path("ansible", "ip-allocation.yml")],
+                limit="infra-vms",
+            ),
+            mock.call(
+                mock.ANY,
+                [
+                    utils.get_data_files_path(
+                        "ansible", "infra-vm-host-configure.yml"),
+                ],
+                limit="infra-vms",
+                extra_vars={"wipe_disks": True},
+            ),
+        ]
+        self.assertEqual(expected_calls, mock_run.call_args_list)
+
     @mock.patch.object(commands.KayobeAnsibleMixin,
                        "run_kayobe_playbooks")
     def test_infra_vm_host_upgrade(self, mock_run):
@@ -1260,36 +1305,8 @@ class TestCase(unittest.TestCase):
             mock.call(
                 mock.ANY,
                 [
-                    utils.get_data_files_path("ansible", "ssh-known-host.yml"),
                     utils.get_data_files_path(
-                        "ansible", "kayobe-ansible-user.yml"),
-                    utils.get_data_files_path("ansible", "apt.yml"),
-                    utils.get_data_files_path("ansible", "dnf.yml"),
-                    utils.get_data_files_path("ansible", "pip.yml"),
-                    utils.get_data_files_path(
-                        "ansible", "kayobe-target-venv.yml"),
-                    utils.get_data_files_path("ansible", "users.yml"),
-                    utils.get_data_files_path("ansible", "dev-tools.yml"),
-                    utils.get_data_files_path(
-                        "ansible", "disable-selinux.yml"),
-                    utils.get_data_files_path("ansible", "network.yml"),
-                    utils.get_data_files_path("ansible", "firewall.yml"),
-                    utils.get_data_files_path("ansible", "tuned.yml"),
-                    utils.get_data_files_path("ansible", "sysctl.yml"),
-                    utils.get_data_files_path("ansible", "disable-glean.yml"),
-                    utils.get_data_files_path(
-                        "ansible", "disable-cloud-init.yml"),
-                    utils.get_data_files_path("ansible", "time.yml"),
-                    utils.get_data_files_path("ansible", "mdadm.yml"),
-                    utils.get_data_files_path("ansible", "luks.yml"),
-                    utils.get_data_files_path("ansible", "lvm.yml"),
-                    utils.get_data_files_path("ansible",
-                                              "docker-devicemapper.yml"),
-                    utils.get_data_files_path(
-                        "ansible", "kolla-ansible-user.yml"),
-                    utils.get_data_files_path("ansible", "kolla-pip.yml"),
-                    utils.get_data_files_path(
-                        "ansible", "kolla-target-venv.yml"),
+                        "ansible", "overcloud-host-configure.yml"),
                 ],
                 limit="overcloud",
             ),
@@ -1302,10 +1319,67 @@ class TestCase(unittest.TestCase):
             mock.call(
                 mock.ANY,
                 [
-                    utils.get_data_files_path("ansible", "kolla-host.yml"),
                     utils.get_data_files_path("ansible", "docker.yml"),
                     utils.get_data_files_path(
                         "ansible", "swift-block-devices.yml"),
+                    utils.get_data_files_path(
+                        "ansible", "compute-libvirt-host.yml"),
+                ],
+                limit="overcloud",
+            ),
+        ]
+        self.assertEqual(expected_calls, mock_run.call_args_list)
+
+        expected_calls = [
+            mock.call(
+                mock.ANY,
+                "bootstrap-servers",
+            ),
+        ]
+        self.assertEqual(expected_calls, mock_kolla_run.call_args_list)
+
+    @mock.patch.object(commands.KayobeAnsibleMixin,
+                       "run_kayobe_playbooks")
+    @mock.patch.object(commands.KollaAnsibleMixin,
+                       "run_kolla_ansible_overcloud")
+    def test_overcloud_host_configure_wipe_disks(self, mock_kolla_run,
+                                                 mock_run):
+        command = commands.OvercloudHostConfigure(TestApp(), [])
+        parser = command.get_parser("test")
+        parsed_args = parser.parse_args(["--wipe-disks"])
+
+        result = command.run(parsed_args)
+        self.assertEqual(0, result)
+
+        expected_calls = [
+            mock.call(
+                mock.ANY,
+                [utils.get_data_files_path("ansible", "ip-allocation.yml")],
+                limit="overcloud",
+            ),
+            mock.call(
+                mock.ANY,
+                [
+                    utils.get_data_files_path(
+                        "ansible", "overcloud-host-configure.yml"),
+                ],
+                limit="overcloud",
+                extra_vars={"wipe_disks": True},
+            ),
+            mock.call(
+                mock.ANY,
+                [utils.get_data_files_path("ansible", "kolla-ansible.yml")],
+                tags="config",
+                ignore_limit=True,
+            ),
+            mock.call(
+                mock.ANY,
+                [
+                    utils.get_data_files_path("ansible", "docker.yml"),
+                    utils.get_data_files_path(
+                        "ansible", "swift-block-devices.yml"),
+                    utils.get_data_files_path(
+                        "ansible", "compute-libvirt-host.yml"),
                 ],
                 limit="overcloud",
             ),
@@ -1426,9 +1500,7 @@ class TestCase(unittest.TestCase):
 
     @mock.patch.object(commands.KayobeAnsibleMixin,
                        "run_kayobe_playbooks")
-    @mock.patch.object(commands.KollaAnsibleMixin,
-                       "run_kolla_ansible_overcloud")
-    def test_overcloud_host_upgrade(self, mock_kolla_run, mock_run):
+    def test_overcloud_host_upgrade(self, mock_run):
         command = commands.OvercloudHostUpgrade(TestApp(), [])
         parser = command.get_parser("test")
         parsed_args = parser.parse_args([])
@@ -1441,49 +1513,34 @@ class TestCase(unittest.TestCase):
                 mock.ANY,
                 [
                     utils.get_data_files_path(
-                        "ansible", "kayobe-target-venv.yml"),
-                    utils.get_data_files_path(
-                        "ansible", "kolla-target-venv.yml"),
-                    utils.get_data_files_path(
-                        "ansible", "overcloud-docker-sdk-upgrade.yml"),
-                    utils.get_data_files_path(
-                        "ansible", "overcloud-etc-hosts-fixup.yml"),
-                ],
-                limit="overcloud",
-            ),
-            mock.call(
-                mock.ANY,
-                [utils.get_data_files_path("ansible", "kolla-ansible.yml")],
-                ignore_limit=True,
-                tags="config",
-            ),
-            mock.call(
-                mock.ANY,
-                [
-                    utils.get_data_files_path(
-                        "ansible", "time.yml"),
+                        "ansible", "overcloud-host-upgrade.yml"),
                 ],
                 limit="overcloud",
             ),
         ]
         self.assertEqual(expected_calls, mock_run.call_args_list)
 
-        expected_calls = [
-            mock.call(
-                mock.ANY,
-                "chrony-cleanup",
-            ),
-        ]
-        self.assertEqual(expected_calls, mock_kolla_run.call_args_list)
-
+    @mock.patch.object(commands.KayobeAnsibleMixin,
+                       "run_kayobe_playbooks")
     @mock.patch.object(commands.KollaAnsibleMixin,
                        "run_kolla_ansible_overcloud")
-    def test_overcloud_database_backup(self, mock_run):
+    def test_overcloud_database_backup(self, mock_kolla_run, mock_run):
         command = commands.OvercloudDatabaseBackup(TestApp(), [])
         parser = command.get_parser("test")
         parsed_args = parser.parse_args([])
         result = command.run(parsed_args)
         self.assertEqual(0, result)
+
+        expected_calls = [
+            mock.call(
+                mock.ANY,
+                [utils.get_data_files_path("ansible", "kolla-ansible.yml")],
+                tags="config",
+                ignore_limit=True,
+            ),
+        ]
+        self.assertEqual(expected_calls, mock_run.call_args_list)
+
         expected_calls = [
             mock.call(
                 mock.ANY,
@@ -1491,16 +1548,30 @@ class TestCase(unittest.TestCase):
                 extra_args=[]
             ),
         ]
-        self.assertEqual(expected_calls, mock_run.call_args_list)
+        self.assertEqual(expected_calls, mock_kolla_run.call_args_list)
 
+    @mock.patch.object(commands.KayobeAnsibleMixin,
+                       "run_kayobe_playbooks")
     @mock.patch.object(commands.KollaAnsibleMixin,
                        "run_kolla_ansible_overcloud")
-    def test_overcloud_database_backup_incremental(self, mock_run):
+    def test_overcloud_database_backup_incremental(self, mock_kolla_run,
+                                                   mock_run):
         command = commands.OvercloudDatabaseBackup(TestApp(), [])
         parser = command.get_parser("test")
         parsed_args = parser.parse_args(["--incremental"])
         result = command.run(parsed_args)
         self.assertEqual(0, result)
+
+        expected_calls = [
+            mock.call(
+                mock.ANY,
+                [utils.get_data_files_path("ansible", "kolla-ansible.yml")],
+                tags="config",
+                ignore_limit=True,
+            ),
+        ]
+        self.assertEqual(expected_calls, mock_run.call_args_list)
+
         expected_calls = [
             mock.call(
                 mock.ANY,
@@ -1508,16 +1579,37 @@ class TestCase(unittest.TestCase):
                 extra_args=["--incremental"]
             ),
         ]
-        self.assertEqual(expected_calls, mock_run.call_args_list)
+        self.assertEqual(expected_calls, mock_kolla_run.call_args_list)
 
+    @mock.patch.object(commands.KayobeAnsibleMixin,
+                       "run_kayobe_playbooks")
     @mock.patch.object(commands.KollaAnsibleMixin,
                        "run_kolla_ansible_overcloud")
-    def test_overcloud_database_recover(self, mock_run):
+    def test_overcloud_database_recover(self, mock_kolla_run, mock_run):
         command = commands.OvercloudDatabaseRecover(TestApp(), [])
         parser = command.get_parser("test")
         parsed_args = parser.parse_args([])
         result = command.run(parsed_args)
         self.assertEqual(0, result)
+
+        expected_calls = [
+            mock.call(
+                mock.ANY,
+                [utils.get_data_files_path("ansible", "kolla-ansible.yml")],
+                tags="config",
+                ignore_limit=True,
+            ),
+            mock.call(
+                mock.ANY,
+                [
+                    utils.get_data_files_path("ansible",
+                                              "kolla-openstack.yml"),
+                ],
+                ignore_limit=True,
+            ),
+        ]
+        self.assertEqual(expected_calls, mock_run.call_args_list)
+
         expected_calls = [
             mock.call(
                 mock.ANY,
@@ -1525,16 +1617,38 @@ class TestCase(unittest.TestCase):
                 extra_vars={}
             ),
         ]
-        self.assertEqual(expected_calls, mock_run.call_args_list)
+        self.assertEqual(expected_calls, mock_kolla_run.call_args_list)
 
+    @mock.patch.object(commands.KayobeAnsibleMixin,
+                       "run_kayobe_playbooks")
     @mock.patch.object(commands.KollaAnsibleMixin,
                        "run_kolla_ansible_overcloud")
-    def test_overcloud_database_recover_force_host(self, mock_run):
+    def test_overcloud_database_recover_force_host(self, mock_kolla_run,
+                                                   mock_run):
         command = commands.OvercloudDatabaseRecover(TestApp(), [])
         parser = command.get_parser("test")
         parsed_args = parser.parse_args(["--force-recovery-host", "foo"])
         result = command.run(parsed_args)
         self.assertEqual(0, result)
+
+        expected_calls = [
+            mock.call(
+                mock.ANY,
+                [utils.get_data_files_path("ansible", "kolla-ansible.yml")],
+                tags="config",
+                ignore_limit=True,
+            ),
+            mock.call(
+                mock.ANY,
+                [
+                    utils.get_data_files_path("ansible",
+                                              "kolla-openstack.yml"),
+                ],
+                ignore_limit=True,
+            ),
+        ]
+        self.assertEqual(expected_calls, mock_run.call_args_list)
+
         expected_calls = [
             mock.call(
                 mock.ANY,
@@ -1544,7 +1658,7 @@ class TestCase(unittest.TestCase):
                 }
             ),
         ]
-        self.assertEqual(expected_calls, mock_run.call_args_list)
+        self.assertEqual(expected_calls, mock_kolla_run.call_args_list)
 
     @mock.patch.object(commands.KayobeAnsibleMixin,
                        "run_kayobe_playbooks")
@@ -2000,6 +2114,50 @@ class TestCase(unittest.TestCase):
         ]
         self.assertEqual(expected_calls, mock_run.call_args_list)
 
+    @mock.patch.object(commands.KayobeAnsibleMixin,
+                       "run_kayobe_playbooks")
+    def test_overcloud_host_image_build(self, mock_run):
+        command = commands.OvercloudHostImageBuild(TestApp(), [])
+        parser = command.get_parser("test")
+        parsed_args = parser.parse_args([])
+
+        result = command.run(parsed_args)
+        self.assertEqual(0, result)
+
+        expected_calls = [
+            mock.call(
+                mock.ANY,
+                [
+                    utils.get_data_files_path(
+                        "ansible", "overcloud-host-image-build.yml"),
+                ],
+                extra_vars={},
+            ),
+        ]
+        self.assertEqual(expected_calls, mock_run.call_args_list)
+
+    @mock.patch.object(commands.KayobeAnsibleMixin,
+                       "run_kayobe_playbooks")
+    def test_overcloud_host_image_build_force_rebuild(self, mock_run):
+        command = commands.OvercloudHostImageBuild(TestApp(), [])
+        parser = command.get_parser("test")
+        parsed_args = parser.parse_args(["--force-rebuild"])
+
+        result = command.run(parsed_args)
+        self.assertEqual(0, result)
+
+        expected_calls = [
+            mock.call(
+                mock.ANY,
+                [
+                    utils.get_data_files_path(
+                        "ansible", "overcloud-host-image-build.yml"),
+                ],
+                extra_vars={"overcloud_host_image_force_rebuild": True},
+            ),
+        ]
+        self.assertEqual(expected_calls, mock_run.call_args_list)
+
     @mock.patch.object(commands.KayobeAnsibleMixin,
                        "run_kayobe_playbooks")
     def test_overcloud_deployment_image_build(self, mock_run):
